API docs for “spamfighter.plugins”

# Package s.plugins

Part of spamfighter View Source

Базовый каталог плагинов.

Module | null_partner_authorizer_provider | Плагин, реализующий авторизацию партнеров без логинов/паролей (доверительный вариант).
Module | sample_domain_provider | Плагин, реализующий корневой домен в качестве возможного примера организации.
Module | static_domain_provider | Плагин, реализующий статический домен по умолчанию.
Package | test | Тесты на плагины.